@@ -13,6 +13,7 @@
 #include <numeric>
 
 #include <OpenImageIO/Imath.h>
+#include <OpenImageIO/color.h>
 #include <OpenImageIO/platform.h>
 
 #include <OpenEXR/IlmThreadPool.h>
@@ -1026,6 +1027,15 @@ OpenEXROutput::spec_to_header(ImageSpec& spec, int subimage,
         }
     }
 
+    // Set color interop ID from colorspace
+    if (spec.get_string_attribute("colorInteropID").empty()) {
+        const ColorConfig& colorconfig(ColorConfig::default_colorconfig());
+        string_view colorspace = spec.get_string_attribute("oiio:ColorSpace");
+        string_view interop_id = colorconfig.get_color_interop_id(colorspace);
+        if (!interop_id.empty())
+            spec.attribute("colorInteropID", interop_id);
+    }
+
     // Deal with all other params
     for (const auto& p : spec.extra_attribs)
         put_parameter(p.name().string(), p.type(), p.data(), header);
